@@ -4,22 +4,27 @@
 #'
 #' @return Plot
 #' @export
+#' @importFrom ggplot2 ggplot
 #'
 #' @examples
 #' f8 <- function(x) {-(x[[1]]+x[[2]]) + .1*(x[[1]] - x[[2]])^2}
-#' ContourFunctions::cf_func(f8, xlim=c(0,100), ylim=c(0,100))
+#' if (requireNamespace("ContourFunctions", quietly = TRUE)) {
+#'   ContourFunctions::cf_func(f8, xlim=c(0,100), ylim=c(0,100))
+#' }
 #' m8 <- mixopt_coorddesc(par=list(mopar_ordered(0:100), mopar_ordered(0:100)),
 #'                        fn=f8, track = TRUE)
 #' plot_track(m8)
 #'
 #' library(ggplot2)
 #' library(dplyr)
-#' ContourFunctions::cf_func(f8, xlim=c(0,100), ylim=c(0,100),
-#'                           gg = TRUE) +
-#'   geom_point(data=as.data.frame(matrix(unlist(m8$track$par),
-#'                                 ncol=2, byrow=TRUE)) %>%
-#'                     bind_cols(newbest=m8$track$newbest),
-#'              aes(V1, V2, color=newbest))
+#' if (requireNamespace("ContourFunctions", quietly = TRUE)) {
+#'   ContourFunctions::cf_func(f8, xlim=c(0,100), ylim=c(0,100),
+#'                             gg = TRUE) +
+#'     geom_point(data=as.data.frame(matrix(unlist(m8$track$par),
+#'                                   ncol=2, byrow=TRUE)) %>%
+#'                       bind_cols(newbest=m8$track$newbest),
+#'                aes(V1, V2, color=newbest))
+#' }
 plot_track <- function(out) {
   stopifnot(!is.null(out$track))
   dflist <- list()
@@ -48,7 +53,12 @@ plot_track <- function(out) {
   # dftall <- tidyr::pivot_longer(cols=colnames(df))
   # ggplot2::ggplot(df)
   # gridExtra::grid.arrange(plots)
-  do.call(gridExtra::grid.arrange, plots)
+
+  if (requireNamespace("gridExtra", quietly = TRUE)) {
+    do.call(gridExtra::grid.arrange, plots)
+  } else {
+    warning("Install gridExtra for this to display properly.")
+  }
 }
 if (F) {
   pt <- mixopt_coorddesc(par=list(mopar_cts(2,8),
